# Copyright (c) 2000-2006, JPackage Project
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
#
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the
#    distribution.
# 3. Neither the name of the JPackage Project nor the names of its
#    contributors may be used to endorse or promote products derived
#    from this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
# A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
# OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
# LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
# DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
# THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
# OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#
%def_disable gcj_support


Name: jpackage-utils
Version: 1.7.3
Release: alt6
Epoch: 0
Summary: JPackage utilities
License: JPackage License
Url: http://www.jpackage.org/
Source0: %name-%version.tar.bz2
Patch0: %name-enable-gcj-support.patch
Patch1: %name-openjdk-1.7.0-alt-version.patch
Group: Development/Java

Packager: Java Maintainers Team <java@packages.altlinux.org>

BuildArch: noarch
AutoReqProv: no
BuildRequires: awk, grep
BuildRequires: rpm-build-java
Requires: rpm-build-java
Requires: /bin/egrep, /bin/sed, /usr/bin/perl
Requires: /bin/bash

%description
Utilities for the JPackage Project <http://www.jpackage.org/>:

* %_bindir/build-classpath
                                build the Java classpath in a portable manner
* %_bindir/build-jar-repository
                                build a jar repository in a portable manner
* %_bindir/rebuild-jar-repository
                                rebuild a jar repository in a portable manner
                                (after a jvm change...)
* %_bindir/build-classpath-directory
                                build the Java classpath from a directory
* %_bindir/diff-jars
                                show jar content differences
* %_bindir/jvmjar
                                install jvm extensions
* %_bindir/create-jar-links
                                create custom jar links
* %_bindir/clean-binary-files
                                remove binary files from sources
* %_bindir/check-binary-files
                                check for presence of unexpected binary files
* %_datadir/java-utils/java-functions
                                shell script functions library for Java
                                applications
* %_sysconfdir/java/jpackage-release
                                string identifying the currently installed
                                JPackage release
* %_sysconfdir/java/java.conf
                                system-wide Java configuration file
* %_sysconfdir/rpm/macros.d/jpackage
                                RPM macros for Java packagers and developers
* %_docdir/%name-%version/jpackage-policy
                                Java packaging policy for packagers and
                                developers

It contains also the License, man pages, documentation, XSL files of general
use with maven2, a header file for spec files etc.

%prep
%setup -q

%if_enabled gcj_support
%patch0 -p0
%endif
%patch1 -p2

%build
echo "JPackage release 1.7 (%distribution) for %buildarch" \
 > etc/jpackage-release

%install
# Pull macros out of macros.jpackage and emulate them during install for
# smooth bootstrapping experience.
for dir in \
    jvmdir jvmjardir jvmprivdir \
    jvmlibdir jvmdatadir jvmsysconfdir \
    jvmcommonlibdir jvmcommondatadir jvmcommonsysconfdir \
    javadir jnidir javadocdir mavendepmapdir; do
  export _${dir}=$(rpm --eval $(grep -E "^%%_${dir}\b" misc/macros.jpackage | awk '{ print $2 }'))
done

export _javadir="%_javadir"

install -dm 755 $RPM_BUILD_ROOT%_bindir
install -dm 755 $RPM_BUILD_ROOT%_sysconfdir/{java,rpm/macros.d}
%if_enabled gcj_support
install -dm 755 $RPM_BUILD_ROOT%_sysconfdir/java/security
install -dm 755 $RPM_BUILD_ROOT%_sysconfdir/java/security/security.d
%endif
install -dm 755 $RPM_BUILD_ROOT$_jvmdir
install -dm 755 $RPM_BUILD_ROOT$_jvmjardir
install -dm 755 $RPM_BUILD_ROOT$_jvmprivdir
install -dm 755 $RPM_BUILD_ROOT$_jvmlibdir
install -dm 755 $RPM_BUILD_ROOT$_jvmdatadir
install -dm 755 $RPM_BUILD_ROOT$_jvmsysconfdir
install -dm 755 $RPM_BUILD_ROOT$_jvmcommonlibdir
install -dm 755 $RPM_BUILD_ROOT$_jvmcommondatadir
install -dm 755 $RPM_BUILD_ROOT$_jvmcommonsysconfdir
install -dm 755 $RPM_BUILD_ROOT$_javadir
install -dm 755 $RPM_BUILD_ROOT$_jnidir
install -dm 755 $RPM_BUILD_ROOT$_javadir-{utils,ext,1.3.1,1.4.0,1.4.1,1.4.2,1.5.0,1.6.0,1.7.0}
install -dm 755 $RPM_BUILD_ROOT$_jnidir-{ext,1.3.1,1.4.0,1.4.1,1.4.2,1.5.0,1.6.0,1.7.0}
install -dm 755 $RPM_BUILD_ROOT$_javadocdir
install -dm 755 $RPM_BUILD_ROOT$_mavendepmapdir

%if_enabled gcj_support
cat > bin/rebuild-security-providers << EOF
#!/bin/bash
# Rebuild the list of security providers in classpath.security

secfiles="/usr/lib/security/classpath.security /usr/lib64/security/classpath.security"

for secfile in \$secfiles; do
  # check if this classpath.security file exists
  [ -f "\$secfile" ] || continue

  sed -i '/^security\.provider\./d' "\$secfile"

  count=0
  for provider in \$(ls /etc/java/security/security.d)
  do
    count=\$((count + 1))
    echo "security.provider.\${count}=\${provider#*-}" >> "\$secfile"
  done
done
EOF
%endif

install -pm 755 bin/* $RPM_BUILD_ROOT%_bindir
install -pm 644 etc/font.properties $RPM_BUILD_ROOT%_sysconfdir/java

# Create an initial (empty) depmap
echo -e "<dependencies>\\n" > $RPM_BUILD_ROOT${_mavendepmapdir}/maven2-depmap.xml
echo -e "</dependencies>\\n" >> $RPM_BUILD_ROOT${_mavendepmapdir}/maven2-depmap.xml

cat > etc/java.conf << EOF
# System-wide Java configuration file                                -*- sh -*-
#
# JPackage Project <http://www.jpackage.org/>

# Location of jar files on the system
JAVA_LIBDIR=${_javadir}

# Location of arch-specific jar files on the system
JNI_LIBDIR=${_jnidir}

# Root of all JVM installations
JVM_ROOT=${_jvmdir}

# You can define a system-wide JVM root here if you're not using the default one
#JAVA_HOME=\$JVM_ROOT/java

# Options to pass to the java interpreter
JAVACMD_OPTS=
EOF

install -pm 644 etc/java.conf $RPM_BUILD_ROOT%_sysconfdir/java
install -pm 644 etc/jpackage-release $RPM_BUILD_ROOT%_sysconfdir/java
install -pm 644 java-utils/* $RPM_BUILD_ROOT${_javadir}-utils
install -pm 644 misc/macros.jpackage $RPM_BUILD_ROOT%_sysconfdir/rpm/macros.d/jpackage
%__mkdir_p $RPM_BUILD_ROOT%_mandir/man1
install -pm 644 man/* $RPM_BUILD_ROOT%_mandir/man1
%__mkdir_p $RPM_BUILD_ROOT${_javadir}-utils/xml
install -pm 644 xml/* $RPM_BUILD_ROOT${_javadir}-utils/xml
cat > jpackage-list <<EOF
%%dir %_sysconfdir/java
%%dir $_jvmdir
%%dir $_jvmjardir
%%dir $_jvmprivdir
%%dir $_jvmdatadir
%%dir $_jvmsysconfdir
%%dir $_jvmcommonlibdir
%%dir $_jvmcommondatadir
%%dir $_jvmcommonsysconfdir
%%dir $_javadir
%%dir $_javadir-*
%%dir $_jnidir
%%dir $_jnidir-*
%%dir $_javadocdir
%%dir $_mavendepmapdir
$_javadir-utils/*
%%config %_sysconfdir/java/jpackage-release
%%config(noreplace) %_sysconfdir/java/java.conf
%%config(noreplace) %_sysconfdir/java/font.properties
%%config(noreplace) %_sysconfdir/rpm/macros.d/jpackage
%%config(noreplace) $_mavendepmapdir/maven2-depmap.xml
EOF

%files -f jpackage-list
%_bindir/*
%_mandir/man1/*
%doc LICENSE.txt HEADER.JPP doc/* etc/httpd-javadoc.conf
%if_enabled gcj_support
%_sysconfdir/java/security
%_sysconfdir/java/security/security.d
%endif


%changelog
* Tue Nov 20 2007 Igor Vlasenko <viy@altlinux.ru> 0:1.7.3-alt6
- fixed openjdk misdetection

* Sun Jul 29 2007 Damir Shayhutdinov <damir@altlinux.ru> 0:1.7.3-alt5
- Added directory for Java 1.7.0 (openjdk) #12409

* Sun Jul 08 2007 Damir Shayhutdinov <damir@altlinux.ru> 0:1.7.3-alt4
- Do not override system macros (#12223)
- Requires and buildrequires rpm-build-java

* Fri Apr 06 2007 Damir Shayhutdinov <damir@altlinux.ru> 0:1.7.3-alt3
- Disabled gcj support 

* Mon Feb 12 2007 Damir Shayhutdinov <damir@altlinux.ru> 0:1.7.3-alt2
- Some spec cleanup 

* Wed Feb 07 2007 Damir Shayhutdinov <damir@altlinux.ru> 0:1.7.3-alt1
- Initial build for ALT Linux (based on Fedora 6 spec)

